package com.fs.aiSipCall.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.aiSipCall.RemoteCommon;
import com.fs.aiSipCall.domain.AiSipCallBizGroup;
import com.fs.aiSipCall.mapper.AiSipCallBizGroupMapper;
import com.fs.aiSipCall.service.IAiSipCallBizGroupService;
import com.fs.aiSipCall.utils.SipLogUtil;
import com.fs.common.utils.DateUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * aiSIP外呼技能组Service业务层处理
 * 
 * @author fs
 * @date 2026-03-06
 */
@Service
public class AiSipCallBizGroupServiceImpl extends ServiceImpl<AiSipCallBizGroupMapper, AiSipCallBizGroup> implements IAiSipCallBizGroupService {

    private static final Logger log = SipLogUtil.createSipLogger(AiSipCallBizGroupServiceImpl.class);

    /**
     * 查询aiSIP外呼技能组
     * 
     * @param groupId aiSIP外呼技能组主键
     * @return aiSIP外呼技能组
     */
    @Override
    public AiSipCallBizGroup selectAiSipCallBizGroupByGroupId(Long groupId)
    {
        return baseMapper.selectAiSipCallBizGroupByGroupId(groupId);
    }

    /**
     * 查询aiSIP外呼技能组列表
     * 
     * @param aiSipCallBizGroup aiSIP外呼技能组
     * @return aiSIP外呼技能组
     */
    @Override
    public List<AiSipCallBizGroup> selectAiSipCallBizGroupList(AiSipCallBizGroup aiSipCallBizGroup)
    {
        //先使用远程技能组
        String result = RemoteCommon.sendGet(RemoteCommon.REMOTE_ADDERSS_PREFIX + RemoteCommon.BUSIGROUP_LIST_API);
        if(StringUtils.isNotBlank(result)){
            JSONObject jsonObject = JSONObject.parseObject(result);
            if(jsonObject.getInteger("code") == 0){
                String data = jsonObject.getString("data");
                return JSONObject.parseArray(data, AiSipCallBizGroup.class);
            }else{
                log.error("获取技能组接口失败:{}", jsonObject.getString("msg"));
            }
        }else{
            log.error("获取技能组接口失败:接口返回为空");
        }
        return null;
    }

    /**
     * 新增aiSIP外呼技能组
     * 
     * @param aiSipCallBizGroup aiSIP外呼技能组
     * @return 结果
     */
    @Override
    public int insertAiSipCallBizGroup(AiSipCallBizGroup aiSipCallBizGroup)
    {
        aiSipCallBizGroup.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertAiSipCallBizGroup(aiSipCallBizGroup);
    }

    /**
     * 修改aiSIP外呼技能组
     * 
     * @param aiSipCallBizGroup aiSIP外呼技能组
     * @return 结果
     */
    @Override
    public int updateAiSipCallBizGroup(AiSipCallBizGroup aiSipCallBizGroup)
    {
        return baseMapper.updateAiSipCallBizGroup(aiSipCallBizGroup);
    }

    /**
     * 批量删除aiSIP外呼技能组
     * 
     * @param groupIds 需要删除的aiSIP外呼技能组主键
     * @return 结果
     */
    @Override
    public int deleteAiSipCallBizGroupByGroupIds(Long[] groupIds)
    {
        return baseMapper.deleteAiSipCallBizGroupByGroupIds(groupIds);
    }

    /**
     * 删除aiSIP外呼技能组信息
     * 
     * @param groupId aiSIP外呼技能组主键
     * @return 结果
     */
    @Override
    public int deleteAiSipCallBizGroupByGroupId(Long groupId)
    {
        return baseMapper.deleteAiSipCallBizGroupByGroupId(groupId);
    }
}
